API Reference
=============

.. autosummary::
    :toctree: _autosummary
    :template: autosummary-module.rst
    :recursive:

    blacs.analysis_submission
    blacs.compile_and_restart
    blacs.device_base_class
    blacs.experiment_queue
    blacs.front_panel_settings
    blacs.notifications
    blacs.output_classes
    blacs.plugins
    blacs.tab_base_classes
    blacs.__main__
